@@ -7,6 +7,8 @@ import plotly.express as px
 import pandas as pd
 from numpy import nan
 
+from grblogtools.helpers import fill_default_parameters
+from grblogtools.helpers import add_categorical_descriptions
 
 # Log Status Codes
 class logstatus:
@@ -130,7 +132,7 @@ class logpattern:
             "Model has (?P<NumPWLObjVars>\d+) piecewise-linear objective terms?"
         ),
         re.compile("Model has (?P<NumGenConstrs>\d+) general constraints?"),
-        re.compile("Loaded MIP start with objective (?P<MIPStart>.*)$"),
+        re.compile("Loaded user MIP start with objective (?P<MIPStart>.*)$"),
         re.compile("Pool objective bound (?P<PoolObjBound>.*)$"),
         re.compile("Solution count (?P<SolCount>\d+)"),
         re.compile(
@@ -695,7 +697,7 @@ def _copy_keys(source, target):
             target[key] = source[key].iloc[0]
 
 
-def get_dataframe(logfiles, timelines=False, verbose=False, merged_logs=False):
+def get_dataframe(logfiles, timelines=False, verbose=False, merged_logs=False, prettyparams=False):
     """Create a dataframe with all stats of the logs
 
     - timelines=True: also create dictionary of timelines of all logs
@@ -728,7 +730,7 @@ def get_dataframe(logfiles, timelines=False, verbose=False, merged_logs=False):
                 header.append(len(loglines))
             else:
                 header = [0, len(loglines)]
-            for h in range(len(header) - 1):
+            for i,h in enumerate(range(len(header) - 1)):
                 log_info = get_log_info(loglines[header[h] : header[h + 1]], verbose)
                 if log_info is None:
                     print(f"error processing {logfile}")
@@ -737,6 +739,9 @@ def get_dataframe(logfiles, timelines=False, verbose=False, merged_logs=False):
                 log_info["LogFilePath"] = os.path.abspath(logfile)
                 log_info["Log"] = os.path.splitext(os.path.basename(logfile))[0]
 
+                # add counter if using merged_logs:
+                log_info["LogFilePath"] += f"({i+1})"
+
                 if log_info.get("ModelFilePath"):
                     log_info["ModelFile"] = os.path.basename(
                         log_info["ModelFilePath"]
@@ -766,7 +771,9 @@ def get_dataframe(logfiles, timelines=False, verbose=False, merged_logs=False):
         summary["Seed"] = summary["Seed (Parameter)"].fillna(0).astype(int).astype(str)
         summary = summary.drop(labels="Seed (Parameter)", axis=1)
 
-    summary = summary.replace("-", nan)
+    summary = fill_default_parameters(summary.replace("-", nan))
+    if prettyparams:
+        summary = add_categorical_descriptions(summary)
 
     if timelines:
 
